summaryrefslogtreecommitdiff
path: root/dbaccess/source/filter/xml/xmlExport.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'dbaccess/source/filter/xml/xmlExport.cxx')
-rw-r--r--dbaccess/source/filter/xml/xmlExport.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/dbaccess/source/filter/xml/xmlExport.cxx b/dbaccess/source/filter/xml/xmlExport.cxx
index 53fbca513dfe..7afd9beb6652 100644
--- a/dbaccess/source/filter/xml/xmlExport.cxx
+++ b/dbaccess/source/filter/xml/xmlExport.cxx
@@ -389,9 +389,9 @@ void ODBExport::exportDataSource()
if ( eToken == XML_TOKEN_INVALID )
{
// for properties which are not REMOVEABLE, we care for their state, and
// only export them if they're not DEFAULTed
- if ( ( pProperties->Attributes & PropertyAttribute::REMOVEABLE ) == 0 )
+ if ( ( pProperties->Attributes & PropertyAttribute::REMOVABLE ) == 0 )
{
PropertyState ePropertyState = xSettingsState->getPropertyState( pProperties->Name );
if ( PropertyState_DEFAULT_VALUE == ePropertyState )
@@ -389,9 +389,9 @@ void ODBExport::exportDataSource()
if ( eToken == XML_TOKEN_INVALID )
{
- // for properties which are not REMOVEABLE, we care for their state, and
+ // for properties which are not REMOVABLE, we care for their state, and
// only export them if they're not DEFAULTed